@@ -11,7 +11,6 @@
 #include <PowerDevilProfileSettings.h>
 #include <kwinkscreenhelpereffect.h>
 #include <powerdevil_debug.h>
-#include <powerdevilbackendinterface.h>
 #include <powerdevilcore.h>
 
 #include <QAction>
@@ -118,13 +117,18 @@ void DPMS::onIdleTimeout(std::chrono::milliseconds /*timeout*/)
 {
     // Do not inhibit anything even if idleTimeout reaches because we are inhibit
     if (!m_inhibitScreen && isSupported()) {
+        qCDebug(POWERDEVIL) << "DPMS: starting to fade out";
         Q_EMIT startFade();
+    } else {
+        qCDebug(POWERDEVIL) << "DPMS: inhibited (or unsupported), not turning off display";
     }
 }
 
 void DPMS::turnOffOnIdleTimeout()
 {
-    const int keyboardBrightness = backend()->keyboardBrightness();
+    qCDebug(POWERDEVIL) << "DPMS: triggered on idle timeout, turning off display and keyboard backlight";
+
+    const int keyboardBrightness = core()->keyboardBrightnessController()->brightness();
     if (keyboardBrightness > 0) {
         m_oldKeyboardBrightness = keyboardBrightness;
         setKeyboardBrightnessHelper(0);
@@ -141,16 +145,18 @@ void DPMS::setKeyboardBrightnessHelper(int brightness)
 
 void DPMS::triggerImpl(const QVariantMap &args)
 {
+    QString type = args.value(QStringLiteral("Type")).toString();
+    qCDebug(POWERDEVIL) << "DPMS: triggered from externally, type:" << (type.isEmpty() ? "TurnOn" : type);
+
     QString KEYBOARD_BRIGHTNESS = QStringLiteral("KeyboardBrightness");
     if (args.contains(KEYBOARD_BRIGHTNESS)) {
-        backend()->setKeyboardBrightness(args.value(KEYBOARD_BRIGHTNESS).toInt());
+        core()->keyboardBrightnessController()->setBrightness(args.value(KEYBOARD_BRIGHTNESS).toInt());
         return;
     }
 
     if (!isSupported()) {
         return;
     }
-    QString type = args.value(QStringLiteral("Type")).toString();
     if (m_lockBeforeTurnOff && (type == "TurnOff" || type == "ToggleOnOff")) {
         lockScreen();
     }
@@ -213,8 +219,10 @@ void DPMS::registerStandardIdleTimeout()
     }
 
     if (PowerDevil::PolicyAgent::instance()->screenLockerActive()) {
+        qCDebug(POWERDEVIL) << "DPMS: registering idle timeout (screen already locked) after" << m_idleTimeoutWhenLocked;
         registerIdleTimeout(m_idleTimeoutWhenLocked);
     } else {
+        qCDebug(POWERDEVIL) << "DPMS: registering idle timeout after" << m_idleTimeoutWhenUnlocked;
         registerIdleTimeout(m_idleTimeoutWhenUnlocked);
     }
 }
@@ -230,10 +238,12 @@ void DPMS::onScreenLockerActiveChanged(bool active)
 
     if (m_isActivatingLock) {
         // entering lockscreen - fast display turn-off if the config calls for it
+        qCDebug(POWERDEVIL) << "DPMS: registering idle timeout (screen lock activating) after" << m_idleTimeoutWhenActivatingLock;
         registerIdleTimeout(m_idleTimeoutWhenActivatingLock);
         // if we're locking but about to suspend, wait until onResumeFromSuspend() to register the timeout
     } else if (!active) {
         // restoring normal idleTimeout
+        qCDebug(POWERDEVIL) << "DPMS: registering idle timeout (screen unlocked) after" << m_idleTimeoutWhenUnlocked;
         registerIdleTimeout(m_idleTimeoutWhenUnlocked);
     }
 }
